@@ -19,8 +19,13 @@ def Loggs(name, logsAll=True):
         logger = logging.getLogger(name)
 
         # solo cuando se indique se mostraran todos los logs
-        if logsAll:
-            coloredlogs.install()
+        if os.environ.get('PRODUCTION', False):
+            from logbook import Logger, StreamHandler
+            import sys
+            StreamHandler(sys.stdout).push_application()
+            return Logger(name)
+        elif logsAll:
+            coloredlogs.install(level='DEBUG', logger=logger)
         else:
-            coloredlogs.install(logger=logger)
+            coloredlogs.install()
         return logger
