@@ -7,6 +7,7 @@ import copy
 import base64
 import datetime
 import traceback
+from urllib import parse
 import _thread
 import asyncio  # Requerido
 from jaeger_client import Config
@@ -179,24 +180,29 @@ class Microservices(BaseClass, ABC):
 
             class myHandler(BaseHTTPRequestHandler):
                 def do_GET(self):
+                    message_parts = []
+                    code = 0
                     try:
                         if healthcheck() and smoketest():
-                            self.send_header('Content-type', 'text/html')
-                            self.end_headers()
-                            self.send_response(200)
-                            self.wfile.write(b'ok')
-                            return
+                            code = 200
+                            message_parts.append("OK")
                     except:
-                        pass
+                        code = 500
 
-                    self.send_header('Content-type', 'text/html')
+                    if code < 100:
+                        code = 500
+                        message_parts.append("ERROR")
+
+                    message = '\r\n'.join(message_parts)
+                    self.send_response(code)
+                    self.send_header(
+                        'Content-Type', 'text/plain; charset=utf-8')
                     self.end_headers()
-                    self.send_response(500)
-                    self.wfile.write(b'ERROR')
+                    self.wfile.write(message.encode('utf-8'))
 
-            self.logs.info('[HealthCheck] listening on 0.0.0.0:80')
-            server = HTTPServer(('', 80), myHandler)
-            server.serve_forever()
+        self.logs.info('[HealthCheck] listening on 0.0.0.0:80')
+        server = HTTPServer(('', 80), myHandler)
+        server.serve_forever()
 
     def coro_manager(self, coro):
         """
@@ -389,6 +395,7 @@ class Microservices(BaseClass, ABC):
 
         # Diccionario de la respuesta
         Resp = {}
+
         # Crear una copia de la respuesta
         dataResponse = data
 
